@@ -61,7 +61,7 @@ class Asset:
                 if self.knowledge_end_dt:
                     parts.add(str(to_timestamp(self.knowledge_end_dt)))
 
-        return abs(farmhash.hash64(''.join(sorted(list(parts)))))
+        return farmhash.fingerprint64(''.join(sorted(list(parts))))
 
     @property
     def key_hash(self):
