@@ -10,6 +10,13 @@ from timeit import default_timer as timer
 from bakplane.extensions.base import ExecutionStatistics
 
 
+def to_timestamp(dt: datetime) -> int:
+    ts = Timestamp()
+    ts.FromDatetime(dt)
+
+    return ts.seconds
+
+
 def to_proto_timestamp(dt: datetime) -> Timestamp:
     ts = Timestamp()
     ts.FromDatetime(dt)
